@@ -60,7 +60,7 @@ class IPythonExtension:
         data = kwargs.get('data', None)
         if data is not None:
             asyncio.create_task(self.cP.plot(data, **self._plot_magic_args))
-        if not self._supress_output:
+        if self._supress_output is False:
             self._original_display_pub_publish(*args, **kwargs)
         
 
@@ -68,8 +68,9 @@ class IPythonExtension:
 
         # Build args from the cell info
         if hasattr(info, 'cell_id'):
-            self._plot_magic_args['id'] = info.cell_id
-            self._plot_magic_args['ipythonCellId'] = info.cell_id
+            if info.cell_id is not None:
+                self._plot_magic_args['id'] = info.cell_id
+                self._plot_magic_args['ipythonCellId'] = info.cell_id
         if hasattr(info, 'raw_cell'):
             self._plot_magic_args['ipythonRawCell'] = info.raw_cell
 
@@ -83,7 +84,6 @@ class IPythonExtension:
         
         # Clean up the current cell id
         self._magic_current_cell_id = None
-        self._last_display_pub_output = None
         self._plot_magic_args = {}
            
 
